@@ -139,8 +139,8 @@ class Client_v1(AbstractContextManager):
             self.base_url + url, data=data, timeout=self.timeout)
         logger.debug(f'HTTP Response: {response}')
         response.raise_for_status()
-        validate.XML(response.content)
-        # TODO: Don't we want to parse this similar to in get()?
+        validate.RESTful_XML(response.content)
+        # TODO: Do we want to 'parse' this, so it is similar to what is returned from get()?
         return response.content
 
     def delete(self, url):
@@ -162,7 +162,7 @@ class Client_v1(AbstractContextManager):
         response = self.http.delete(self.base_url + url, timeout=self.timeout)
         logger.debug(f'HTTP Response: {response}')
         response.raise_for_status()
-        # TODO: Don't we want to parse this similar to in get()?
+        # TODO: Do we want to 'parse' this, so it is similar to what is returned from get()?
         return response.content
 
     def create_object(self, object, data):
@@ -200,7 +200,7 @@ class Client_v1(AbstractContextManager):
         Returns:
           Created record as a multi-level dictionary.
         """
-        return self.post("/" + object, data, timeout=self.timeout)
+        return self.post("/" + object, data)
 
 
 class Client(Client_v1):
