@@ -42,3 +42,15 @@ def test_get_all(client):
     assert_that(site).contains_key('state')
     assert_that(site).contains_key('city')
     assert_that(site).contains_key('country')
+
+
+@pytest.mark.vcr()
+def test_create_object_site(client: Client):
+    # Act
+    site = client.create_object("site", {
+        'name':'Test site 123',
+        'info':'A site created by automated testing (netdot-sites-manager).'
+    })
+
+    # Assert
+    assert_that(site).is_not_none()
